<img src="figs/LANCET_EUROPE_LOGO.png" alt="drawing" width="270"/>  

<div align="justify">

This project is licensed under GNU General Public License version 3 ([GPL-3](https://www.gnu.org/licenses/gpl-3.0))

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)    

# Indicator 1.3.6: Climatic Suitability for Ticks

## Introduction

Tick-borne diseases (TBDs) are the most common vector-borne diseases in the Northern Hemisphere. **Lyme disease (LD)** is the most frequent TBD in Europe, with over 200,000 cases reported per year in Western Europe alone. The second most prevalent TBD is **tick-borne encephailitis (TBE)**, caused by virus of the *Flaviviridae* family, also known as the TBE-virus. There is evidence of the spread of tick species of public health relevance towards higher altitudes and latitudes in the Northern Hemisphere. For 2025, the indicator has been updated to include more species of ticks, including a wider range of *Ixodes* ticks and two species of *Hyalomma*, a genus of ticks known to transmit Crimean Congo Haemorrhagic Fever (CCHF). CCHF has very high case fatality and is considered an emerging threat in Europe. 

This indicator produces annual grid products of the length of the seasons (i.e. number of months per year) suitable for *Ixodes* and *Hyalomma* ticks to engage in questing and enable survival at a resolution of ~9 km. Additionally, it is possible to average results to administrative regions, such as NUTS3 and country. These outputs will indicate new areas of high exposure, as well as serve as tools to advise policy-makers of where and when to target prevention strategies.

## Methods

This indicator is derived from a threshold-based model. Suitability for a particular month is defined as the coincidence of average monthly temperature, relative humidity and daylength, weighted against the percentage of suitable land in the grid cell. 

#### Data sources

<div align="left">

| Variable | Source | Spatial Resolution | Temporal range used | 
| ------ | ------ | ------ | ------ |
| Monthly 2 meter dew point temperature | [ERA5-Land (monthly)](https://cds.climate.copernicus.eu/cdsapp#!/dataset/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1951 - Dec 2022 |
| Monthly 2 meter temperature | [ERA5-Land (monthly)](https://cds.climate.copernicus.eu/cdsapp#!/dataset/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1951 - Dec 2022 |
| Land cover | [CORINE](https://land.copernicus.eu/pan-european/corine-land-cover/clc2018) | 100m | 2018 |

<div align="justify">

## Content

This repository is organized into branches, with each branch corresponding to the respective year of report release.

For the 2025 report, a Python class named SuitableMonthsThresholds has been developed. It consolidates all threshold-based indicators and is defined in the auxiliary functions file. The class requires two inputs: a species identifier ("Hyalomma" or "Ixodes") and a year. Once initialized, it automatically computes the monthly suitability DataFrame for that year and generates several built-in plots.

The main analysis is conducted in LCDE.ipynb. This notebook first calculates baseline suitability, followed by current suitability and its changes. It then computes NUTS3-level suitability time series from 1951 to the present, stratified by elevation. These results are further analyzed and visualized in tickMaps.ipynb, and related to other covariates under study, such as population.

The Baseline/ folder contains suitability results for the baseline period, while the 2015-2024/ folder includes results for the current period. The Outputs/ folder contains all final tables and figures used in the report.

To access the results for a specific year, simply select the corresponding branch from the dropdown menu (instead of "main"), as illustrated in the image below.

<img src="figs/branches.jpg" height="150">

**Find [here](https://earth.bsc.es/gitlab/ghr/lcde-ticks/-/blob/2024/) the branch of this repository corresponding to the latest report (2024).**

## Authors

##### - [Adrià San José Plana](https://www.bsc.es/san-jose-plana-adria)
##### - [Gina E C Charnley](https://www.bsc.es/ca/charnley-georgina-eva-ceres)
##### - [Rachel Lowe](https://www.bsc.es/lowe-rachel)

##### Contact: georgina.charnley@bsc.es
